#!/usr/bin/perl
#
# hvac.pl v0.1 - BlueLava HVAC AddOn module for BlueLava v0.4.3
# (c) 2005 Vladislav Staroselskiy (inet@vladstar.pp.ru)
#
# BlueLava v0.4.3
# (c) 2001-2004  Ian Wilkinson (ian@sgtwilko.f9.co.uk)
# (c) 1999 Bruce Locke  (blocke@shivan.org)
#
# Generates html code for X10 HVAC system (TXB16), using decode table "P".
# Requires the following modifications to BlueLava:
# 
# 1) make sure, that you have 755 mode for file hvac.pl:
# chmod 755 hvac.pl
# 2) Add the following string into bluelava.cgi file:
# require "hvac.pl";
# 3) Insert "html_hvac_table" subroutine call into htmlgen.pl file, under 
# "generate_status_page" function between html_table_end() and html_footer():
# --- htmlgen.pl begin ---
# html_status_table($message);
# html_table_end();
# html_hvac_table(); ### this is the string you need to insert w/o this comment
# html_footer();      
# --- htmlgen.pl end ---
# 4) Edit $hvac_code in this file to reflect your HVAC device 'house' code
#
# Released under the GPL v2... see COPYING for details
# This software comes without any warranty...
#

$hvac_house_code = "J";
$hvac_addon_copyright = "<p>BlueLava HVAC AddOn - &copy; 2005  Vladislav Staroselskiy (<a href=\"mailto:inet\@vladstar.pp.ru\">inet\@vladstar.pp.ru</a>)</p>";

sub html_hvac_table
{
  html_table_start();
  html_table_header("HVAC TXB16");
  html_hvac_table_device($hvac_code,$hvac_addon_copyright);
  html_table_end();
}

sub html_hvac_table_device
{
  local ($code, $copyright) = @_;

  my @decode_table_p_mode=([9,"on","<b>HeatOn</b>"],[10,"on","<b>CoolOn</b>"],[11,"on","<b>AutoOn</b>"],[12,"on","<b>FanOn</b>"],[12,"off","<b>FanOff</b>"],[9,"off","<b>SystemOff</b>"],[13,"on","<b><i>SetBackOn</i></b>"],[13,"off","<b><i>SetBackOff</i></b>"],[14,"on","&#177;6F/3C"],[15,"on","&#177;8F/4C"],[16,"on","&#177;10F/5C"],[14,"off","&#177;12F/6C"],[15,"off","&#177;14F/7C"],[16,"off","&#177;16F/8C"]);
  my @decode_table_p_temp=([1,"on","65F/13C"],[2,"on","66F/14C"],[3,"on","67F/15C"],[4,"on","68F/16C"],[5,"on","69F/17C"],[6,"on","70F/18C"],[7,"on","71F/19C"],[8,"on","72F/20C"],[1,"off","73F/21C"],[2,"off","74F/22C"],[3,"off","75F/23C"],[4,"off","76F/24C"],[5,"off","77F/25C"],[6,"off","78F/26C"],[7,"off","79F/27C"],[8,"off","80F/28C"]);

  if ( $config_settings{"table_use_gradient"} eq "yes")
  {
    $row_color = $row_color + $row_colorchange;
  }
  $row_color_hex = sprintf ("#%06x", $row_color);

  html_hvac_table_print_row("HVAC Mode & SetBack Mode and Delta (F/C)",@decode_table_p_mode);
  html_hvac_table_print_row("Set Temperature (F/C)",@decode_table_p_temp);
  print "<tr><td><font size=\"-1\">$copyright</font></td></tr>\n";
}


sub html_hvac_table_print_row
{
  local ($row_header, @array) = @_;
  print "<td bgcolor=\"#$label_device_bg\"><font color=\"#$label_device_fg\" size=\"-1\"><b>$row_header</b></font></td>";
  print "<tr><td bgcolor=\"$row_color_hex\"><font size=\"-1\">";
  for($i=0;$i<=$#array;$i++) {
    print "<a href=\"$bluelava_url/bluelava.cgi?action=$array[$i][1]&device=$hvac_house_code$array[$i][0]\">".$array[$i][2]."</a> ";
  }
  print "</font></td></tr>\n";
}

# end of hvac.pl
1;
